Authorization

Trait Authorization 

pub trait Authorization {
    // Required method
    fn get_access_token<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<String>> + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
A trait for providing authorization tokens for client requests.

Required Methods

fn get_access_token<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<String>> + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get a valid access token.

The implementation of this method may perform extra actions under the hood, e.g. refreshing expired tokens.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors